@@ -7,7 +7,8 @@ from tabulate import tabulate
 
 from .parsing_primitives import parse_relative_object_metadata_struct, parse_table_head, parse_data_page_header, \
     ACCESSHEADER, MEMO, parse_table_data, TDEF_HEADER
-from .utils import categorize_pages, parse_type, TYPE_MEMO, TYPE_TEXT, TYPE_BOOLEAN, read_db_file
+from .utils import categorize_pages, parse_type, TYPE_MEMO, TYPE_TEXT, TYPE_BOOLEAN, read_db_file, numeric_to_string, \
+    TYPE_96_bit_17_BYTES
 
 # Page sizes
 PAGE_SIZE_V3 = 0x800
@@ -283,10 +284,7 @@ class AccessTable(object):
         :return: parsed relative record metadata
         """
         if self.version > 3:
-            reverse_record = reverse_record[null_table_length + 1:]
-            # Not sure why we sometimes get an extra 0
-            if len(reverse_record) > 1 and reverse_record[0] == 0:
-                reverse_record = reverse_record[1:]
+            reverse_record = reverse_record[null_table_length:]
             return parse_relative_object_metadata_struct(reverse_record, version=self.version)
         # Parse relative metadata.
         # Metadata is from the end of the record(reverse_record is used here)
@@ -349,12 +347,6 @@ class AccessTable(object):
                 rel_end = relative_record_metadata.var_len_count
             else:
                 rel_end = relative_offsets[i + 1]
-            # Not sure why
-            if self.version > 3:
-                if rel_end > len(original_record):
-                    rel_end = rel_end & 0xff
-                if rel_start > len(original_record):
-                    rel_start = rel_start & 0xff
 
             # if rel_start and rel_end are the same there is no data in this slot
             if rel_start == rel_end:
@@ -362,12 +354,21 @@ class AccessTable(object):
                 continue
 
             relative_obj_data = original_record[rel_start + jump_table_addition: rel_end + jump_table_addition]
+            # Parse types that require column data here, call parse_type on all other types
             if column.type == TYPE_MEMO:
                 try:
                     parsed_type = self._parse_memo(relative_obj_data, column)
                 except ConstructError:
                     logging.warning("Failed to parse memo field. Using data as bytes")
                     parsed_type = relative_obj_data
+            elif column.type == TYPE_96_bit_17_BYTES:
+                if len(relative_obj_data) != 17:
+                    logging.warning(f"Relative numeric field has invalid length {len(relative_obj_data)}, expected 17")
+                    parsed_type = relative_obj_data
+                else:
+                    # Get scale or None
+                    scale = column.get('various', {}).get('scale', 6)
+                    parsed_type = numeric_to_string(relative_obj_data, scale)
             else:
                 parsed_type = parse_type(column.type, relative_obj_data, len(relative_obj_data), version=self.version)
             self.parsed_table[col_name].append(parsed_type)
@@ -434,7 +435,12 @@ class AccessTable(object):
         parsed_memo = MEMO.parse(relative_obj_data)
         if parsed_memo.memo_length & 0x80000000:
             logging.debug("memo data inline")
-            memo_data = relative_obj_data[parsed_memo.memo_end:]
+            inline_memo_length = parsed_memo.memo_length & 0x3FFFFFFF
+            if len(relative_obj_data) < parsed_memo.memo_end + inline_memo_length:
+                logging.warning("Inline memo field has invalid length using full data")
+                memo_data = relative_obj_data[parsed_memo.memo_end:]
+            else:
+                memo_data = relative_obj_data[parsed_memo.memo_end:parsed_memo.memo_end + inline_memo_length]
             memo_type = TYPE_TEXT
         elif parsed_memo.memo_length & 0x40000000:
             logging.debug("LVAL type 1")
